@@ -1,8 +1,8 @@
-version="0.9.21.0.004"
+version="0.9.21.0.009"
 
-date = '2021-03-17'
+date = '2021-10-14'
 
-dpi = 128
+dpi = 64
 # coding:utf-8
 
 from ImportDependence import *
@@ -1472,7 +1472,8 @@ class AppForm(QMainWindow):
                 df = df.drop(i, 1)
 
         df = df.apply(pd.to_numeric, errors='coerce')
-        df = df.dropna(axis='columns')
+        # df = df.dropna(axis='columns')
+        df = df.dropna(axis='rows')
 
         return (df)
 
